@@ -1,4 +1,5 @@
 import functools
+import importlib.util
 import os
 import sys
 
@@ -6,7 +7,6 @@ import click
 import pkg_resources
 
 from octue.cloud.deployment.google.cloud_run.deployer import CloudRunDeployer
-from octue.cloud.deployment.google.dataflow.deployer import DataflowDeployer
 from octue.cloud.pub_sub.service import Service
 from octue.definitions import CHILDREN_FILENAME, FOLDER_DEFAULTS, MANIFEST_FILENAME, VALUES_FILENAME
 from octue.exceptions import DeploymentError
@@ -16,6 +16,14 @@ from octue.runner import Runner
 from twined import Twine
 
 
+# Import the Dataflow deployer only if the `apache-beam` package is available (due to installing `octue` with the
+# `dataflow` extras option).
+APACHE_BEAM_PACKAGE_AVAILABLE = bool(importlib.util.find_spec("apache_beam"))
+
+if APACHE_BEAM_PACKAGE_AVAILABLE:
+    from octue.cloud.deployment.google.dataflow.deployer import DataflowDeployer
+
+
 global_cli_context = {}
 
 
@@ -279,6 +287,12 @@ def cloud_run(octue_configuration_path, service_id, update, no_cache):
 @click.option("--image-uri", type=str, default=None, help="The actual image URI to use when creating the Dataflow job.")
 def dataflow(octue_configuration_path, service_id, no_cache, update, dataflow_job_only, image_uri):
     """Deploy an app as a Google Dataflow streaming job."""
+    if not APACHE_BEAM_PACKAGE_AVAILABLE:
+        raise ImportWarning(
+            "To use this CLI command, you must install `octue` with the `dataflow` option e.g. "
+            "`pip install octue[dataflow]`"
+        )
+
     if update and not service_id:
         raise DeploymentError("If updating a service, you must also provide the `--service-id` argument.")
 
